pub enum Macro {
Builtin(Transfer, String),
Library(String, Program),
}Expand description
Macro types that can be called by the interpreter
Variants
Builtin(Transfer, String)
A function written in the implementation language
Library(String, Program)
Parameter name with a sequence of statements that are inserted into the program when called